@@ -1,6 +1,7 @@
-import types
-import logging
 from botocore.auth import SigV4Auth
+import logging
+import types
+from urllib.parse import urlparse
 
 logger = logging.getLogger("awscli.clidriver")
 
@@ -26,7 +27,13 @@ def building_argument_table(argument_table, operation_model, event_name, session
 
     # build and register a before-sign hook that modifies the request URL and monkeypatches the request signer
     def before_sign(request, operation_name, **kwargs):
-        request.url = url
+        # Replace request URL scheme, netloc and prepend path from config
+        logger.debug("URLs: %s <-> %s", request.url, url)
+        old = urlparse(request.url)
+        new = urlparse(url)
+        path = (new.path + old.path).replace('//', '/')
+        request.url = old._replace(scheme=new.scheme, netloc=new.netloc, path=path).geturl()
+        logger.debug("URL: %s", request.url)
 
         # Rename transport header. Addresses:
         # The service name : "BackplaneExecutionService" identified from the payload does not agree with the service name : "DynamoDB_20120810" specified in the transport header
